@@ -409,14 +409,17 @@ def CLF(X, y, verbose = False, show = False, save_fig = ''):
     y_pred = clf.predict(X)
 
     enc = OneHotEncoder(handle_unknown='ignore')
-    y_ohe = enc.fit_transform(y).toarray()
-        
+    y_ohe = enc.fit_transform( np.array(y).reshape(-1,1) ).toarray()
+    # print(y_ohe)
+    # print(y_prob_ohe)
+
     clf_metrics.append( globals()["log_loss"](y, y_prob) )
     clf_metrics.append( Mean_KLD (y_ohe, y_prob_ohe) )
     clf_metrics.append( globals()["average_precision_score"](y, y_prob) )
     clf_metrics.append( globals()["brier_score_loss"](y, y_prob) )
     clf_metrics.append( globals()["roc_auc_score"](y, y_prob) )
-    precisions, recalls, _ = precision_recall_curve(y, y_prob)
+    
+    precisions, recalls, _ = precision_recall_curve(y, y_prob, pos_label = max(y)) # set pos_label for cases when y is not {0,1} or {-1,1}
     clf_metrics.append( globals()["auc"](recalls, precisions) )
 
     
